# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-07-19 13:37:16
@LastEditTime: 2023-05-25 09:47:46
@LastEditors: HuangJianYi
@Description: 
"""
import threading
from seven_framework.console.base_console import *
from seven_cloudapp_frame.models.enum import *
from seven_cloudapp_frame.models.frame_base_model import *
from seven_cloudapp_frame.models.task_base_model import *
from seven_cloudapp_frame.libs.customize.seven_helper import *
from seven_cloudapp_frame.libs.common import *
from seven_cloudapp_frame.models.db_models.task.task_gear_count_model import *
from seven_cloudapp_frame.models.db_models.task.task_info_model import *
from seven_cloudapp_frame.models.db_models.task.task_count_model import *


class TaskConsoleModel():
    """
    :description: 任务控制台业务模型
    """

    def console_task_queue(self):
        """
        :description: 控制台统计上报
        :return: 
        :last_editors: HuangJianYi
        """
        for i in range(10):
            j = threading.Thread(target=self.process_task_queue, args=[i])
            j.start()

    def process_task_queue(self, mod_value):
        """
        :description: 处理档位任务队列
        :param mod_value: 当前队列值
        :return: 
        :last_editors: HuangJianYi
        """
        print(f"{TimeHelper.get_now_format_time()} 档位任务队列{mod_value}启动")

        while True:
            try:
                time.sleep(0.1)

                redis_init = SevenHelper.redis_init()
                redis_key = f"task_gear_list:{mod_value}"
                task_queue_json = redis_init.lindex(redis_key, index=0)
                if not task_queue_json:
                    time.sleep(1)
                    continue
                try:
                    create_day = SevenHelper.get_now_day_int()
                    create_month = SevenHelper.get_now_month_int()
                    task_queue_dict = SevenHelper.json_loads(task_queue_json)
                    task_info_model = TaskInfoModel()
                    db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
                    task_count_model = TaskCountModel(sub_table=FrameBaseModel().get_business_sub_table("task_count_tb", {"app_id": task_queue_dict["app_id"]}), db_transaction=db_transaction)
                    task_gear_count_model = TaskGearCountModel(db_transaction=db_transaction)
                    task_info_dict = task_info_model.get_dict("act_id=%s and module_id=%s and task_type=%s", params=[task_queue_dict["act_id"], task_queue_dict["module_id"], task_queue_dict["task_type"]])

                    task_gear_count = task_gear_count_model.get_entity("act_id=%s and task_type=%s and user_id=%s and create_day=%s and module_id=%s", params=[task_queue_dict["act_id"], task_queue_dict["task_type"], task_queue_dict["user_id"], create_day, task_queue_dict["module_id"]])
                    db_transaction.begin_transaction()
                    if not task_gear_count:
                        task_gear_count = TaskGearCount()
                        task_gear_count.app_id = task_queue_dict["app_id"]
                        task_gear_count.act_id = task_queue_dict["act_id"]
                        task_gear_count.module_id = task_queue_dict["module_id"]
                        task_gear_count.user_id = task_queue_dict["user_id"]
                        task_gear_count.open_id = task_queue_dict["open_id"]
                        task_gear_count.task_type = task_queue_dict["task_type"]
                        task_gear_count.now_count = task_queue_dict["now_count"]
                        task_gear_count.create_day = create_day
                        task_gear_count.create_month = create_month
                        task_gear_count.create_date = SevenHelper.get_now_datetime()
                        task_gear_count.remark = task_queue_dict["remark"]
                        task_gear_count_model.add_entity(task_gear_count)
                    else:
                        task_gear_count.now_count = decimal.Decimal(task_gear_count.now_count) + decimal.Decimal(task_queue_dict["now_count"])
                        task_gear_count.remark = task_gear_count.remark + "," + task_queue_dict["remark"] if  task_gear_count.remark else task_queue_dict["remark"]
                        task_gear_count_model.update_table("now_count=%s,remark=%s,modify_date=%s", "id=%s", params=[task_gear_count.now_count, task_gear_count.remark, task_gear_count.create_date, task_gear_count.id])
                    if task_info_dict:
                        #判断子任务是否完成
                        config_json = SevenHelper.json_loads(task_info_dict["config_json"])
                        if config_json and config_json.__contains__("gear_list"):
                            task_base_model = TaskBaseModel()
                            now_count = decimal.Decimal(task_base_model.get_gear_task_count(task_queue_dict["act_id"], task_queue_dict["module_id"], task_queue_dict["user_id"], task_queue_dict["task_type"], task_info_dict["complete_type"])) + decimal.Decimal(task_queue_dict["now_count"])
                            task_count_list = task_count_model.get_list("act_id=%s and module_id=%s and user_id=%s and task_type=%s", params=[task_queue_dict["act_id"], task_queue_dict["module_id"], task_queue_dict["user_id"], task_queue_dict['task_type']])
                            config_json = config_json["gear_list"]
                            for sub_config_json in config_json:
                                task_count = task_base_model.init_task_count(task_info_dict, task_count_list, sub_config_json["id"])
                                if task_count.complete_count == 1:
                                    continue
                                task_count_id_md5 = CryptoHelper.md5_encrypt_int(f"{task_queue_dict['act_id']}_{task_queue_dict['module_id']}_{task_queue_dict['task_type']}_{sub_config_json['id']}_{task_queue_dict['user_id']}")
                                if now_count >= decimal.Decimal(sub_config_json["gear"]):
                                    task_count = TaskCount()
                                    task_count.id_md5 = task_count_id_md5
                                    task_count.app_id = task_queue_dict["app_id"]
                                    task_count.act_id = task_queue_dict["act_id"]
                                    task_count.module_id = task_queue_dict["module_id"]
                                    task_count.user_id = task_queue_dict["user_id"]
                                    task_count.open_id = task_queue_dict["open_id"]
                                    task_count.task_type = task_queue_dict["task_type"]
                                    task_count.task_sub_type = sub_config_json["id"]
                                    task_count.complete_count = 0
                                    task_count.now_count = 1
                                    task_count.create_date = SevenHelper.get_now_datetime()
                                    task_count.modify_date = SevenHelper.get_now_datetime()
                                    task_count.modify_day = SevenHelper.get_now_day_int()
                                    task_count_model.add_update_entity(task_count, "complete_count=0,now_count=1,modify_date=%s,modify_day=%s", params=[task_count.modify_date, task_count.modify_day])
         
                    result, message = db_transaction.commit_transaction(True)
                    if result == False:
                        raise Exception("执行事务失败", message)
                    redis_init.lpop(redis_key)

                except Exception as ex:
                    logger_error.error(f"档位任务队列{mod_value}异常,json串:{SevenHelper.json_dumps(task_queue_dict)},ex:{traceback.format_exc()}")
                    continue

            except Exception as ex:
                logger_error.error(f"档位任务队列{mod_value}异常,ex:{traceback.format_exc()}")
                time.sleep(5)



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-08-03 15:42:53
@LastEditTime: 2023-05-09 09:37:11
@LastEditors: HuangJianYi
@Description: 奖品模块
"""
from seven_cloudapp_frame.models.enum import *
from seven_cloudapp_frame.handlers.frame_base import *
from seven_cloudapp_frame.models.act_base_model import *
from seven_cloudapp_frame.models.prize_base_model import *
from seven_cloudapp_frame.models.seven_model import PageInfo
from seven_cloudapp_frame.libs.customize.oss2_helper import *


class SaveActPrizeHandler(ClientBaseHandler):
    """
    :description: 保存活动奖品
    """
    def post_async(self):
        """
        :description: 保存活动奖品
        :param app_id：应用标识
        :param act_id: 活动标识
        :param module_id: 活动模块标识
        :param prize_id: 奖品标识
        :param prize_name: 奖品名称
        :param prize_title: 奖品子标题
        :param prize_pic: 奖品图
        :param prize_detail_json: 奖品详情图（json）
        :param goods_id: 商品ID
        :param goods_code: 商品编码
        :param goods_code_list: 多个sku商品编码
        :param goods_type: 物品类型（1虚拟2实物）
        :param prize_type: 奖品类型(1现货2优惠券3红包4参与奖、谢谢参与5预售)
        :param prize_price: 奖品价值
        :param probability: 奖品权重
        :param chance: 概率
        :param prize_limit: 中奖限制数
        :param is_prize_notice: 是否显示跑马灯(1是0否)
        :param prize_total: 奖品总数
        :param is_surplus: 是否显示奖品库存（1显示0-不显示）
        :param lottery_type: 出奖类型（1概率出奖 2强制概率）
        :param tag_name: 标签名称(奖项名称)
        :param tag_id: 标签ID(奖项标识)
        :param is_sku: 是否有SKU
        :param sku_json: sku详情json 注意：所有的参数只能是整形或字符串，如果是对象的参数必须先序列化
        :param sort_index: 排序
        :param is_release: 是否发布（1是0否）
        :param ascription_type: 奖品归属类型（0-活动奖品1-任务奖品）
        :param i1: i1
        :param i2: i2
        :param i3: i3
        :param i4: i4
        :param i5: i5
        :param s1: s1
        :param s2: s2
        :param s3: s3
        :param s4: s4
        :param s5: s5
        :param d1: d1
        :param d2: d2
        :return: 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        module_id = int(self.get_param("module_id", 0))
        prize_id = int(self.get_param("prize_id", 0))
        prize_name = self.get_param("prize_name")
        prize_title = self.get_param("prize_title")
        prize_pic = self.get_param("prize_pic")
        prize_detail_json = self.get_param("prize_detail_json")
        goods_id = self.get_param("goods_id")
        goods_code = self.get_param("goods_code")
        goods_code_list = self.get_param("goods_code_list")
        goods_type = int(self.get_param("goods_type", 0))
        prize_type = int(self.get_param("prize_type", 0))
        prize_price = self.get_param("prize_price")
        probability = self.get_param("probability")
        chance = self.get_param("chance")
        prize_limit = int(self.get_param("prize_limit", 0))
        is_prize_notice = int(self.get_param("is_prize_notice", 0))
        prize_total = int(self.get_param("prize_total", 0))
        is_surplus = int(self.get_param("is_surplus", 0))
        lottery_type = int(self.get_param("lottery_type", 0))
        tag_name = self.get_param("tag_name")
        tag_id = int(self.get_param("tag_id", 0))
        is_sku = int(self.get_param("is_sku", 0))
        sku_json = self.get_param("sku_json")
        ascription_type = int(self.get_param("ascription_type", 0))
        sort_index = int(self.get_param("sort_index", 0))
        is_release = int(self.get_param("is_release", 0))
        i1 = int(self.get_param("i1", 0))
        i2 = int(self.get_param("i2", 0))
        i3 = int(self.get_param("i3", 0))
        i4 = int(self.get_param("i4", 0))
        i5 = int(self.get_param("i5", 0))
        s1 = self.get_param("s1")
        s2 = self.get_param("s2")
        s3 = self.get_param("s3")
        s4 = self.get_param("s4")
        s5 = self.get_param("s5")
        d1 = self.get_param("d1", "1900-01-01 00:00:00")
        d2 = self.get_param("d2", "1900-01-01 00:00:00")

        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        prize_total = invoke_result_data.data["prize_total"] if invoke_result_data.data.__contains__("prize_total") else prize_total
        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "奖品"
        prize_base_model = PrizeBaseModel(context=self)
        invoke_result_data = prize_base_model.save_act_prize(app_id, act_id, module_id, prize_id, prize_name, prize_title, prize_pic, prize_detail_json, goods_id, goods_code, goods_code_list, goods_type, prize_type, prize_price, probability, chance, prize_limit, is_prize_notice, prize_total, is_surplus, lottery_type, tag_name, tag_id, is_sku, sku_json, sort_index, is_release, ascription_type, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        if invoke_result_data.data["is_add"] == True:
            # 记录日志
            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title= title_prefix + ";" + prize_name)
        else:
            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title= title_prefix + ";" + prize_name)
        ref_params = {}
        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success(invoke_result_data.data["new"].id)


class ActPrizeListHandler(ClientBaseHandler):
    """
    :description: 活动奖品列表
    """
    def get_async(self):
        """
        :description: 活动奖品列表
        :param app_id：应用标识
        :param act_id：活动标识
        :param module_id：活动模块标识
        :param prize_name：奖品名称
        :param is_del：是否回收站1是0否
        :param ascription_type：归属类型
        :param page_index：页索引
        :param page_size：页大小
        :return: PageInfo
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        module_id = self.get_param_int("module_id", 0)
        prize_name = self.get_param("prize_name")
        is_del = self.get_param_int("is_del", 0)
        ascription_type = self.get_param_int("ascription_type", -1)
        page_index = self.get_param_int("page_index", 0)
        page_size = self.get_param_int("page_size", 20)

        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_success({"data": []})
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc,id asc"
        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
        if not app_id or not act_id:
            return self.response_json_success({"data": []})
        prize_base_model = PrizeBaseModel(context=self)
        page_list, total = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, ascription_type, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params, field=field, is_cache=False)
        for page in page_list:
            if page.__contains__("prize_detail_json"):
                page["prize_detail_json"] = SevenHelper.json_loads(page["prize_detail_json"]) if page["prize_detail_json"] else []
            if page.__contains__("sku_json"):
                page["sku_json"] = SevenHelper.json_loads(page["sku_json"]) if page["sku_json"] else []
        ref_params = {}
        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
        return self.response_json_success(page_info)


class DeleteActPrizeHandler(ClientBaseHandler):
    """
    :description: 删除活动奖品
    """
    @filter_check_params("prize_id")
    def get_async(self):
        """
        :description: 删除活动奖品
        :param app_id：应用标识
        :param prize_id：奖品标识
        :return: 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        prize_id = int(self.get_param("prize_id", 0))
        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "奖品"
        prize_base_model = PrizeBaseModel(context=self)
        invoke_result_data = prize_base_model.update_act_prize_status(app_id, prize_id, 1)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        self.create_operation_log(operation_type=OperationType.delete.value, model_name="act_prize_tb", title= title_prefix + ";" + invoke_result_data.data["prize_name"])
        ref_params = {}
        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success()


class ReviewActPrizeHandler(ClientBaseHandler):
    """
    :description: 还原活动奖品
    """
    @filter_check_params("prize_id")
    def get_async(self):
        """
        :description: 还原活动奖品
        :param app_id：应用标识
        :param prize_id：奖品标识
        :return: 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        prize_id = int(self.get_param("prize_id", 0))
        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "奖品"
        prize_base_model = PrizeBaseModel(context=self)
        invoke_result_data = prize_base_model.update_act_prize_status(app_id, prize_id, 0)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        self.create_operation_log(operation_type=OperationType.review.value, model_name="act_prize_tb", title= title_prefix + ";" + invoke_result_data.data["prize_name"])
        ref_params = {}
        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success()


class ReleaseActPrizeHandler(ClientBaseHandler):
    """
    :description: 上下架活动奖品
    """
    @filter_check_params("prize_id")
    def get_async(self):
        """
        :description: 上下架活动奖品
        :param app_id：应用标识
        :param prize_id 奖品标识
        :param is_release: 是否发布 1-是 0-否
        :return:
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        prize_id = int(self.get_param("prize_id", 0))
        is_release = int(self.get_param("is_release", 0))
        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "奖品"
        prize_base_model = PrizeBaseModel(context=self)
        invoke_result_data = prize_base_model.release_act_prize(app_id, prize_id, is_release)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        operation_type = OperationType.release.value if is_release == 1 else OperationType.un_release.value
        self.create_operation_log(operation_type=operation_type, model_name="act_prize_tb", title= title_prefix + ";" + invoke_result_data.data["prize_name"])
        ref_params = {}
        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success()


class ActPrizeExportHandler(ClientBaseHandler):
    """
    :description: 导出活动奖品列表
    """
    def get_async(self):
        """
        :description: 导出活动奖品列表
        :param app_id：应用标识
        :param act_id：活动标识
        :param module_id：活动模块标识
        :param prize_name：奖品名称
        :param is_del：是否回收站1是0否
        :param page_size：页大小
        :param page_index：页索引
        :return 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        module_id = int(self.get_param("module_id", 0))
        prize_name = self.get_param("prize_name")
        is_del = int(self.get_param("is_del", -1))
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 500))

        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_success("")
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
        operate_title = invoke_result_data.data["operate_title"] if invoke_result_data.data.__contains__("operate_title") else "奖品列表"


        prize_base_model = PrizeBaseModel(context=self)
        act_prize_list_dict = []
        if page_size <= 500:
            act_prize_list_dict = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, is_del, page_size, page_index, order_by=order_by, condition=condition, params=params, field=field, is_cache=False).data
        else:
            max_page_size = 100
            repeat_count = page_size // max_page_size  # 循环次数
            begin_page_index = page_index * repeat_count  # 开始页码
            for i in range(repeat_count):
                list_dict = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, is_del, max_page_size, begin_page_index + i, order_by=order_by, condition=condition, params=params, field=field, is_cache=False).data
                if len(list_dict) <= 0:
                    break
                act_prize_list_dict.extend(list_dict)
        ref_params = {}
        result_data = self.business_process_executed(act_prize_list_dict, ref_params)
        resource_path = OSS2Helper.export_excel(result_data)
        self.create_operation_log(operation_type=OperationType.export.value, model_name="act_prize_tb", title=operate_title)
        return self.response_json_success(resource_path)

    def business_process_executed(self, result_data, ref_params):
        """
        :description: 执行后事件
        :param result_data:result_data
        :param ref_params: 关联参数
        :return:
        :last_editors: HuangJianYi
        """
        result_list = []
        for act_prize_dict in result_data:
            data_row = {}
            data_row["奖品名称"] = act_prize_dict["prize_name"]
            data_row["奖品子标题"] = act_prize_dict["prize_title"]
            data_row["奖品图"] = act_prize_dict["prize_pic"]
            data_row["商品ID"] = act_prize_dict["goods_id"]
            data_row["商家编码"] = act_prize_dict["goods_code"]
            data_row["奖品类型"] = act_prize_dict["prize_type"]
            data_row["奖品价值"] = str(act_prize_dict["prize_price"])
            data_row["奖品库存"] = act_prize_dict["surplus"]
            data_row["奖品总库存"] = act_prize_dict["prize_total"]
            if act_prize_dict["prize_type"] == 1:
                data_row["奖品类型"] = "现货"
            elif act_prize_dict["prize_type"] == 2:
                data_row["奖品类型"] = "优惠券"
            elif act_prize_dict["prize_type"] == 3:
                data_row["奖品类型"] = "红包"
            elif act_prize_dict["prize_type"] == 4:
                data_row["奖品类型"] = "参与奖"
            else:
                data_row["奖品类型"] = "预售"
            data_row["创建时间"] = TimeHelper.datetime_to_format_time(act_prize_dict["create_date"])
            data_row["是否发布"] = "未发布"
            if act_prize_dict["is_release"] == 1:
                data_row["是否发布"] = "已发布"
            result_list.append(data_row)
        return result_list


# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-08-12 17:38:51
@LastEditTime: 2023-03-13 18:33:04
@LastEditors: HuangJianYi
@Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class InviteHelpModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(InviteHelpModel, self).__init__(InviteHelp, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class InviteHelp:

    def __init__(self):
        super(InviteHelp, self).__init__()
        self.id = 0  # id
        self.id_md5 = 0  # id_md5(act_id+module_id+object_id)md5int
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.module_id = 0  # 模块标识
        self.help_type = 0  # 助力类型（0无1邀请用户）
        self.object_id = 0  # 对象标识
        self.user_id = 0  # 邀请人用户标识
        self.open_id = ""  # 邀请人OpenID
        self.invited_user_id = "" # 受邀人用户标识
        self.invited_open_id = ""  # 受邀人OpenID
        self.invited_user_nick = ""  # 受邀人昵称
        self.invited_avatar = ""  # 受邀人头像
        self.is_handle = 0  # 是否处理（1处理0未处理）
        self.is_invited_handle = 0  #受邀人是否处理（1处理0未处理）
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.create_day = 0  # 创建天
        self.i1 = 0  # i1
        self.i2 = 0  # i2
        self.s1 = ''  # s1
        self.s2 = ''  # s2

    @classmethod
    def get_field_list(self):
        return ['id', 'id_md5', 'app_id', 'act_id', 'module_id', 'help_type', 'object_id', 'user_id', 'open_id', 'invited_user_id', 'invited_open_id', 'invited_user_nick', 'invited_avatar', 'is_handle', 'is_invited_handle', 'create_date', 'create_day', 'i1', 'i2', 's1', 's2']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "invite_help_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-08-02 14:03:12
@LastEditTime: 2023-05-16 10:44:33
@LastEditors: HuangJianYi
@Description: 
"""
from seven_cloudapp_frame.models.enum import PageCountMode
from seven_cloudapp_frame.handlers.frame_base import *
from seven_cloudapp_frame.models.app_base_model import *
from seven_cloudapp_frame.models.act_base_model import *
from seven_cloudapp_frame.models.cms_base_model import *
from seven_cloudapp_frame.models.prize_base_model import *
from seven_cloudapp_frame.models.price_base_model import *


class ActInfoHandler(ClientBaseHandler):
    """
    :description: 获取活动信息
    """
    def get_async(self):
        """
        :description: 获取活动信息
        :param act_id：活动标识
        :return: 
        :last_editors: HuangJianYi
        """
        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        ver_no = invoke_result_data.data["ver_no"] if invoke_result_data.data.__contains__("ver_no") else '1'
        if ver_no == "1":
            self.get_act_info()
        else:
            self.get_act_info_v2()

    def get_act_info(self):
        """
        :description: 获取活动信息V1版本
        :return: 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        app_base_model = AppBaseModel(context=self)
        act_base_model = ActBaseModel(context=self)
        app_info_dict = app_base_model.get_app_info_dict(app_id)
        if not app_info_dict:
            return self.response_json_error("error", "小程序不存在")
        act_info_dict = act_base_model.get_act_info_dict(act_id, True, False)
        if not act_info_dict or act_info_dict["is_del"] == 1 or act_info_dict["app_id"] != app_id:
            return self.response_json_error("error", "活动不存在")
        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)

        act_info_dict["seller_id"] = app_info_dict["seller_id"]
        act_info_dict["store_id"] = app_info_dict["store_id"]
        act_info_dict["store_name"] = app_info_dict["store_name"]
        act_info_dict["store_icon"] = app_info_dict["store_icon"]
        act_info_dict["app_icon"] = app_info_dict["app_icon"]
        act_info_dict["store_user_nick"] = app_info_dict["store_user_nick"]

        act_info_dict = self.business_process_executed(act_info_dict, ref_params={})
        return self.response_json_success(act_info_dict)

    def get_act_info_v2(self):
        """
        :description: 获取活动信息V2版本
        :return: 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        app_base_model = AppBaseModel(context=self)
        act_base_model = ActBaseModel(context=self)
        app_info_dict = app_base_model.get_app_info_dict(app_id, field="id,seller_id,store_id,store_name,store_icon,app_icon")
        if not app_info_dict:
            return self.response_json_error("error", "小程序不存在")
        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        exclude_fields = invoke_result_data.data["exclude_fields"] if invoke_result_data.data.__contains__("exclude_fields") else "is_visit_store,store_url,theme_id,is_release,close_word,start_date,end_date,is_del,finish_menu_config_json,agreement_json,is_fictitious,task_asset_type_json,refund_count,is_finish,is_launch,brand_json,share_desc_json,rule_desc_json,release_date,sort_index,create_date,modify_date,i1,i2,i3,i4,i5,s1,s2,s3,s4,s5,d1,d2"
        act_info_dict = act_base_model.get_act_info_dict(act_id, True, False)
        if not act_info_dict or act_info_dict["is_del"] == 1 or act_info_dict["app_id"] != app_id:
            return self.response_json_error("error", "活动不存在")

        # 店铺配置
        act_info_dict['store'] = {}
        act_info_dict['store']['id'] = app_info_dict['id']
        act_info_dict['store']['seller_id'] = app_info_dict['seller_id']
        act_info_dict['store']['store_id'] = app_info_dict['store_id']
        act_info_dict['store']['is_open'] = act_info_dict['is_visit_store']
        act_info_dict['store']['store_url'] = act_info_dict['store_url']

        # 主题配置
        act_info_dict['theme'] = {}
        act_info_dict['theme']['id'] = act_info_dict['theme_id']
        # 小程序配置
        act_info_dict['mini_program'] = {}
        act_info_dict['mini_program']['is_open'] = act_info_dict['is_release']
        act_info_dict['mini_program']['close_word'] = act_info_dict['close_word']
        act_info_dict['mini_program']['start_date'] = act_info_dict['start_date']
        act_info_dict['mini_program']['end_date'] = act_info_dict['end_date']
        # 分享配置 {"taoword": "", "icon": "", "title": "", "desc": ""}
        act_info_dict["shares"] = {}
        act_info_dict["shares"]["default"] = {"taoword": "", "icon": "", "title": "", "desc": ""}
        if act_info_dict.__contains__("share_desc_json") and act_info_dict["share_desc_json"] not in ['', '{}']:
            share_desc = SevenHelper.json_loads(act_info_dict["share_desc_json"])
            if share_desc.__contains__("default"):
                act_info_dict["shares"] = share_desc
            else:
                act_info_dict["shares"]["default"] = share_desc
        # 规则配置 [{"title":"购买规则","desc":"在此填写规则"}]
        act_info_dict["rules"] = SevenHelper.json_loads(act_info_dict["rule_desc_json"]) if act_info_dict["rule_desc_json"] else []
        # 用户协议或隐私条款配置 [{"title":"购买规则","explain":"在此填写规则"}]
        act_info_dict["purchase_agreement"] = SevenHelper.json_loads(act_info_dict["agreement_json"]) if act_info_dict["agreement_json"] else []
        #品牌配置
        act_info_dict["brands"] = SevenHelper.json_loads(act_info_dict["brand_json"]) if act_info_dict["brand_json"] else {}

        act_info_dict = self.business_process_executed(act_info_dict, ref_params={})
        if act_info_dict:
            for item in exclude_fields.split(','):
                try:
                    del act_info_dict[item]
                except:
                    pass

        return self.response_json_success(act_info_dict)


class ActPrizeListHandler(ClientBaseHandler):
    """
    :description: 活动奖品列表
    """
    def get_async(self):
        """
        :description: 活动奖品列表
        :param act_id: 活动标识
        :param module_id: 活动模块标识
        :param prize_name: 奖品名称
        :param ascription_type: 奖品归属类型（0-活动奖品1-任务奖品）
        :param page_size: 条数
        :param page_index: 页数
        :param page_count_mode：分页模式(0-none 1-total 2-next)
        :return: PageInfo
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        module_id = self.get_param_int("module_id", 0)
        prize_name = self.get_param("prize_name")
        page_index = self.get_param_int("page_index", 0)
        page_size = self.get_param_int("page_size", 10)
        page_count_mode = self.get_param_int("page_count_mode", 1)

        if not app_id or not act_id:
            return self.response_json_success({"data": []})
        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_success({"data": []})
        prize_base_model = PrizeBaseModel(context=self)
        page_count_mode = SevenHelper.get_enum_key(PageCountMode, page_count_mode)
        page_list = prize_base_model.get_act_prize_list(app_id, act_id, module_id, prize_name, 0, 0, page_size, page_index, condition="is_release=1", page_count_mode=page_count_mode)
        if page_count_mode == "total":
            total = page_list[1]
            page_list = self.business_process_executed(page_list[0], ref_params={})
            return_info = PageInfo(page_index, page_size, total, page_list)
        elif page_count_mode == "next":
            is_next = page_list[1]
            page_list = self.business_process_executed(page_list[0], ref_params={})
            return_info = WaterPageInfo(page_list, is_next)
        else:
            return_info = self.business_process_executed(page_list, ref_params={})
        return self.response_json_success(return_info)


class CmsInfoListHandler(ClientBaseHandler):
    """
    :description: 获取位置信息列表
    """
    @filter_check_params("place_id")
    def get_async(self):
        """
        :description: 获取位置信息列表
        :params place_id:位置标识
        :param page_count_mode：分页模式(0-none 1-total 2-next)
        :return 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        place_id = self.get_param_int("place_id", 0)
        page_size = self.get_param_int("page_size", 20)
        page_index = self.get_param_int("page_index", 0)
        page_count_mode = self.get_param_int("page_count_mode", 1)


        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_success({"data": []})
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else None
        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else None
        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
        cms_base_model = CmsBaseModel(context=self)
        page_count_mode = SevenHelper.get_enum_key(PageCountMode, page_count_mode)
        if condition and params:
            page_list = cms_base_model.get_cms_info_list_v2(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, condition=condition, params=params, is_cache=True, page_count_mode=page_count_mode)
        else:
            page_list = cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=True, page_count_mode=page_count_mode)
        if page_count_mode == "total":
            total = page_list[1]
            page_list = self.business_process_executed(page_list[0], ref_params={})
            return_info = PageInfo(page_index, page_size, total, page_list)
        elif page_count_mode == "next":
            is_next = page_list[1]
            page_list = self.business_process_executed(page_list[0], ref_params={})
            return_info = WaterPageInfo(page_list, is_next)
        else:
            return_info = self.business_process_executed(page_list, ref_params={})
        return self.response_json_success(return_info)


class PriceGearListHandler(ClientBaseHandler):
    """
    :description: 获取价格档位列表
    """
    def get_async(self):
        """
        :description: 获取价格档位列表
        :param app_id：应用标识
        :param act_id：活动标识
        :param page_index：页索引
        :param page_size：页大小
        :param page_count_mode：分页模式(0-none 1-total 2-next)
        :return: list
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        page_size = self.get_param_int("page_size", 20)
        page_index = self.get_param_int("page_index", 0)
        page_count_mode = self.get_param_int("page_count_mode", 1)
        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_success({"data": []})
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc"
        page_count_mode = SevenHelper.get_enum_key(PageCountMode, page_count_mode)
        page_list = PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index, order_by, page_count_mode=page_count_mode)
        if page_count_mode == "total":
            total = page_list[1]
            page_list = self.business_process_executed(page_list[0], ref_params={})
            return_info = PageInfo(page_index, page_size, total, page_list)
        elif page_count_mode == "next":
            is_next = page_list[1]
            page_list = self.business_process_executed(page_list[0], ref_params={})
            return_info = WaterPageInfo(page_list, is_next)
        else:
            return_info = self.business_process_executed(page_list, ref_params={})
        return self.response_json_success(return_info)
